'''
Analysing translational movement from image time series.

See the class Movemeter in movemeter.py.
Also see/run the tkgui.py for GUI.
'''

from .version import __version__

from .movemeter import Movemeter
from .roi import gen_grid


